We apply for the Available and Reusable badges.
We believe our artifact meets the requirements for the two badges in the [artifact submission guideline](https://2024.esec-fse.org/track/fse-2024-artifacts).

* **Available**: Our artifact is "Available" as it is publicly accessible through the following repository.
  * Github: [https://github.com/phamquiluan/baro/releases/tag/0.0.9](https://github.com/phamquiluan/baro/releases/tag/0.0.9)

* **Reusable**: Our artifact is "Reusable" (and also "Functional") as we meet the following five criteria (the first four are the criteria for "Functional" badge) mentioned in the [artifact submission guideline](https://2024.esec-fse.org/track/fse-2024-artifacts).
  * _Documented_: We provide the following documents necessary for using our artifact: (1) README, (2) REQUIREMENTS, (3) STATUS, (4) LICENSE, (5) INSTALL, and (6) a copy of the accepted paper.
  * _Consistent & Complete_: We provide concrete steps for reproducing the main experimental results in the paper.
  * _Exercisable_: We provide scripts and related commands for running experiments.
  * _Reusable for Future Researches_: We provide a PyPI package [fse-baro](https://pypi.org/project/fse-baro/) with a Google Colab Notebook ([![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/drive/1znckFNPny9zU0Rlc9_Q99E6h3hsJq764?usp=sharing)
) that provides concrete instructions for running BARO with metrics data. Thus, other researchers can use BARO in their own research.
